@@ -1,16 +1,19 @@
 import binascii
-import yaml
+import os
+
+import json
 
 
 class FileSignatures:
     def __init__(self):
-        with open("file_signatures.yaml", "r") as myfile:
-            data = myfile.read()
-            self.file_sigs = yaml.load(data, Loader=yaml.FullLoader)
+        path = "Data/file_signatures.json"
+        fullpath = os.path.join(os.path.dirname(os.path.abspath(__file__)), path)
+        with open(fullpath, "r", encoding="utf8", errors="ignore") as myfile:
+            self.file_sigs = json.load(myfile)
 
     def open_file_loc(self, file_loc):
-        with open(file_loc, "r") as myfile:
-            r = myfile.read()
+        with open(file_loc, "r", encoding="utf8", errors="ignore") as myfile:
+            r = myfile.readlines()
         return r
 
     def open_binary_scan_magic_nums(self, file_loc):
